set_vectors — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# set_vectors

Surface.set_vectors(vectors_X: ndarray, vectors_Y: ndarray, vectors_Z: ndarray, vectors_name: str = 'vectors')

  Sets/Updates the vectors of the surface.

  Parameters:

    - vectors_X (np.ndarray) – The x values of the vector

    - vectors_Y (np.ndarray) – The y values of the vector

    - vectors_Z (np.ndarray) – The z values of the vector

    - vectors_name (str, optional) – The name of the vector, by default “vectors”